Plot power curve
plot_power_curve.RdCreates a plot showing how power changes with sample size.
Usage
plot_power_curve(
delta,
sd,
alpha = 0.05,
alternative = c("two.sided", "less", "greater"),
n_range = 10:100
)plot_power_curve.RdCreates a plot showing how power changes with sample size.
plot_power_curve(
delta,
sd,
alpha = 0.05,
alternative = c("two.sided", "less", "greater"),
n_range = 10:100
)